@@ -20,7 +20,7 @@ FMTR = {
 }
 
 
-def extract_views_from_urlpatterns(urlpatterns, base=''):
+def extract_views_from_urlpatterns(urlpatterns, base='', namespace=None):
     """
     Return a list of views from a list of urlpatterns.
 
@@ -30,7 +30,13 @@ def extract_views_from_urlpatterns(urlpatterns, base=''):
     for p in urlpatterns:
         if isinstance(p, RegexURLPattern):
             try:
-                views.append((p.callback, base + p.regex.pattern, p.name))
+                if not p.name:
+                    name = p.name
+                elif namespace:
+                    name = '{0}:{1}'.format(namespace, p.name)
+                else:
+                    name = p.name
+                views.append((p.callback, base + p.regex.pattern, name))
             except ViewDoesNotExist:
                 continue
         elif isinstance(p, RegexURLResolver):
@@ -38,7 +44,7 @@ def extract_views_from_urlpatterns(urlpatterns, base=''):
                 patterns = p.url_patterns
             except ImportError:
                 continue
-            views.extend(extract_views_from_urlpatterns(patterns, base + p.regex.pattern))
+            views.extend(extract_views_from_urlpatterns(patterns, base + p.regex.pattern, namespace=(namespace or p.namespace)))
         elif hasattr(p, '_get_callback'):
             try:
                 views.append((p._get_callback(), base + p.regex.pattern, p.name))
@@ -49,7 +55,7 @@ def extract_views_from_urlpatterns(urlpatterns, base=''):
                 patterns = p.url_patterns
             except ImportError:
                 continue
-            views.extend(extract_views_from_urlpatterns(patterns, base + p.regex.pattern))
+            views.extend(extract_views_from_urlpatterns(patterns, base + p.regex.pattern, namespace=namespace))
         else:
             raise TypeError("%s does not appear to be a urlpattern object" % p)
     return views
@@ -61,7 +67,7 @@ class Command(BaseCommand):
                     help="Show urls unsorted but same order as found in url patterns"),
         make_option("--language", "-l", dest="language",
                     help="Set the language code (useful for i18n_patterns)"),
-        make_option("--decorator", "-d", dest="decorator",
+        make_option("--decorator", "-d", action="append", dest="decorator", default=[],
                     help="Show the presence of given decorator on views"),
         make_option("--format", "-f", dest="format_style", default="dense",
                     help="Style of the output. Choices: %s" % FMTR.keys())
@@ -87,8 +93,8 @@ class Command(BaseCommand):
             activate(language)
 
         decorator = options.get('decorator')
-        if decorator is None:
-            decorator = 'login_required'
+        if not decorator:
+            decorator = ['login_required']
 
         format_style = options.get('format_style')
         if format_style not in FMTR:
@@ -116,7 +122,7 @@ class Command(BaseCommand):
                 else:
                     func_globals = {}
 
-                decorators = [decorator] if decorator in func_globals else []
+                decorators = [d for d in decorator if d in func_globals]
 
                 if isinstance(func, functools.partial):
                     func = func.func
@@ -140,7 +146,7 @@ class Command(BaseCommand):
             views = sorted(views)
 
         if format_style == 'aligned':
-            views = [row.split(',') for row in views]
+            views = [row.split(',', 3) for row in views]
             widths = [len(max(columns, key=len)) for columns in zip(*views)]
             views = [
                 '   '.join('{0:<{1}}'.format(cdata, width) for width, cdata in zip(widths, row))
@@ -149,7 +155,7 @@ class Command(BaseCommand):
         elif format_style == 'table':
             # Reformat all data and show in a table format
 
-            views = [row.split(',') for row in views]
+            views = [row.split(',', 3) for row in views]
             widths = [len(max(columns, key=len)) for columns in zip(*views)]
             table_views = []
 
